@@ -5,7 +5,9 @@ import sys
 import semver
 from halo import Halo
 
+from suite_py.commands import common
 from suite_py.lib import logger
+from suite_py.lib import changelog as cl
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.handler.captainhook_handler import CaptainHook
@@ -72,6 +74,7 @@ class Release:
 
     def _create(self):
         latest = self._version.get_latest_version()
+
         if latest != "":
             logger.info(f"The current release is {latest}")
             commits = self._github.get_commits_since_release(self._repo, latest)
@@ -101,6 +104,19 @@ class Release:
             new_version = DEFAULT_VERSION
             message = f"First release with tag {new_version}"
 
+        if cl.changelog_exists():
+            latest_tag, latest_entry = cl.get_latest_entry_with_tag()
+
+            if latest_tag != new_version:
+                if not prompt_utils.ask_confirm(
+                    "You didn't update your changelog, are you sure you want to proceed?"
+                ):
+                    sys.exit()
+            else:
+                message = f"{latest_entry}\n\n# Commits\n\n{message}"
+
+        message = common.ask_for_release_description(message)
+
         self._create_release(new_version, message)
 
         if "deploy" in self._flags and self._flags["deploy"]:
