@@ -1,5 +1,6 @@
 # -*- encoding: utf-8 -*-
-from PyInquirer import prompt
+import inquirer
+from InquirerPy import prompt
 
 
 def ask_confirm(text, default=True):
@@ -26,16 +27,14 @@ def ask_questions_input(question_text, default_text=""):
 
 def ask_questions_editor(question_text, default_text=""):
     questions = [
-        {
-            "type": "editor",
-            "name": "value",
-            "message": question_text,
-            "default": default_text,
-            "eargs": {"editor": "default"},
-        }
+        inquirer.Editor(
+            "value",
+            message=question_text,
+            default=default_text,
+        )
     ]
 
-    answer = prompt(questions)
+    answer = inquirer.prompt(questions)
     return answer["value"]
 
 
@@ -60,7 +59,10 @@ def ask_multiple_choices(question_text, choices):
             "type": "checkbox",
             "name": "values",
             "message": question_text,
-            "choices": [{"name": choice} for choice in choices],
+            "choices": [
+                {"name": choice, "value": choice, "enabled": False}
+                for choice in choices
+            ],
         }
     ]
 
